@@ -62,7 +62,7 @@ GtkWidget 		*btns[4];
 static gchar 		*group_name[4] = { "first", "second", "third", "fourth" };
 static GtkWidget 	*confirm;
 static GtkWidget 	*window;
-static GtkWidget 	*shutter;
+static GtkWidget 	*shutter,*pkey;
 static GConfClient	*client;
 HildonDialog 		*d;
 
